@@ -1,6 +1,4 @@
-import base64
 import dataclasses
-import json
 import logging
 import pathlib
 import sys
@@ -17,6 +15,7 @@ from requests import RequestException
 
 from . import data, util
 from .exceptions import AuthRequiredException
+from .util import decode_token
 
 API_VERSION_PREFIX = '/v2'
 AUTH_SERVER_HOST = '127.0.0.1'
@@ -233,6 +232,19 @@ class RequestUtil:
         self.persist_token(token_type, dataclasses.asdict(token))
 
 
+class Common:
+    def __init__(self, request_util: RequestUtil):
+        self.request_util = request_util
+
+    def get_course_basic_info(self, course_id: str) -> data.BasicCourseInfoResp:
+        """
+        Get basic info about this course.
+        """
+        logging.debug(f"GET basic info about this course.")
+        path = f"/courses/{course_id}/basic"
+        return self.request_util.simple_get_request(path, data.BasicCourseInfoResp)
+
+
 class Student:
     def __init__(self, request_util: RequestUtil):
         self.request_util = request_util
@@ -355,6 +367,7 @@ class Ez:
                                 persist_token if persist_token is not None else in_memory_persist_token)
         self.student: Student = Student(self.util)
         self.teacher: Teacher = Teacher(self.util)
+        self.common: Common = Common(self.util)
 
         logging.basicConfig(format='%(asctime)s %(name)s %(levelname)s : %(message)s', level=logging_level)
 
@@ -364,10 +377,7 @@ class Ez:
         POST check-in.
         """
         logging.debug("POST check-in")
-        # https://stackoverflow.com/questions/38683439/how-to-decode-base64-in-python3
-        b64_string = self.util.get_valid_access_token().token.split(".")[1]
-        b64_string += "=" * ((4 - len(b64_string) % 4) % 4)
-        d = json.loads(base64.b64decode(b64_string))
+        d = decode_token(self.util.get_valid_access_token().token)
 
         @dataclass
         class Account:
